@@ -12,6 +12,9 @@ class DelphinusSettings(BaseModel):
     candles_by_pair_path: str = "/v2/candles-by-pair"
     last_candle_by_pair_path: str = "/v2/candles-by-pair/last"
 
+    usd_price_by_address_path: str = "/v1/price/usd"
+    pair_price_by_address_path: str = "/v1/price/pair"
+
 
 class DelphiSettings(BaseModel):
     url: str
